ParallelGroupQuota
=========================================

.. currentmodule:: alfred3_interact.quota

.. autoclass:: ParallelGroupQuota
   :show-inheritance:




   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
      :toctree:




      ~ParallelGroupQuota.count


      ~ParallelGroupQuota.next







   .. rubric:: Attributes

   .. autosummary::
      :template: autosummary/attribute.rst
      :toctree:


         ~ParallelGroupQuota.DATA_TYPE
         ~ParallelGroupQuota.allfinished
         ~ParallelGroupQuota.full
         ~ParallelGroupQuota.group_type
         ~ParallelGroupQuota.nfinished
         ~ParallelGroupQuota.nopen
         ~ParallelGroupQuota.npending
